package hdl

import (
	"applet/app/admin/lib/validate"
	"applet/app/admin/md"
	svc2 "applet/app/admin/svc/enterprise_manage"
	md2 "applet/app/customer/md"
	"applet/app/customer/svc"
	"applet/app/db"
	"applet/app/db/model"
	"applet/app/e"
	"applet/app/enum"
	"applet/app/utils"
	"github.com/gin-gonic/gin"
	"time"
)

func SelfSupportForSchoolUserUpdate(c *gin.Context) {
	var req md.SelfSupportForSchoolUserUpdateReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	err = svc2.SelfSupportForSchoolUserUpdate(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolUserDelete(c *gin.Context) {
	var req md.SelfSupportForSchoolUserDeleteReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	err = svc2.SelfSupportForSchoolUserDelete(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolStudentList(c *gin.Context) {
	var req md.SelfSupportForSchoolStudentListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	resp, total, err := svc2.SelfSupportForSchoolStudentList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
		"admission_list": []map[string]string{
			{
				"name":  "按班级",
				"value": "admission_type_by_class",
			},
			{
				"name":  "按年级",
				"value": "admission_type_by_grade",
			},
		},
		"collect_face_type_list": []map[string]interface{}{
			{
				"name":  "个采",
				"value": 1,
			},
			{
				"name":  "集采",
				"value": 2,
			},
		},
	}, nil)
	return
}

func SelfSupportForSchoolTeacherList(c *gin.Context) {
	var req md.SelfSupportForSchoolTeacherListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	resp, total, err := svc2.SelfSupportForSchoolTeacherList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
		"collect_face_type_list": []map[string]interface{}{
			{
				"name":  "个采",
				"value": 1,
			},
			{
				"name":  "集采",
				"value": 2,
			},
		},
	}, nil)
	return
}

func SelfSupportForSchoolTeacherUpdate(c *gin.Context) {
	var req md.SelfSupportForSchoolTeacherUpdateReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(0)
	userIdentity, err := userIdentityDb.GetUserIdentity(req.UserIdentityId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if userIdentity == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}
	userIdentity.IdNo = req.IdNo
	userIdentity.Name = req.Name
	_, err = userIdentityDb.UserIdentityUpdate(req.UserIdentityId, userIdentity, "id_no", "name")
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	//更新 self_support_for_user_face_info
	selfSupportForUserFaceInfoDb := db.SelfSupportForUserFaceInfoDb{}
	selfSupportForUserFaceInfoDb.Set(req.UserIdentityId)
	info, err := selfSupportForUserFaceInfoDb.GetSelfSupportForUserFaceInfo()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if info == nil {
		now := time.Now()
		selfSupportForSchoolInfoDb := db.SelfSupportForSchoolInfoDb{}
		selfSupportForSchoolInfoDb.Set(req.EnterpriseId)
		selfSupportForSchoolInfo, err := selfSupportForSchoolInfoDb.GetSelfSupportForSchoolInfo()
		if err != nil {
			return
		}
		if selfSupportForSchoolInfo == nil {
			e.OutErr(c, e.ERR, "当前学校暂未完成《一脸通行入驻》")
			return
		}
		info = &model.SelfSupportForUserFaceInfo{
			EnterpriseId:                    req.EnterpriseId,
			UserIdentityId:                  req.UserIdentityId,
			CollectFaceType:                 req.CollectFaceType,
			SchoolCode:                      selfSupportForSchoolInfo.SchoolCode,
			SchoolStdCode:                   selfSupportForSchoolInfo.SchoolStdCode,
			ParentUserId:                    "",
			ParentLogonId:                   "",
			UserId:                          "",
			SchoolFacePassStatus:            "CLOSE",
			SchoolFacePaymentStatus:         "CLOSE",
			ConcentrateSchoolFacePassStatus: 1,
			CreateAt:                        now.Format("2006-01-02 15:04:05"),
			UpdateAt:                        now.Format("2006-01-02 15:04:05"),
		}
		_, err1 := selfSupportForUserFaceInfoDb.SelfSupportForUserFaceInfoInsert(info)
		if err1 != nil {
			e.OutErr(c, e.ERR, err1.Error())
			return
		}
	} else {
		info.CollectFaceType = req.CollectFaceType
		_, err = selfSupportForUserFaceInfoDb.SelfSupportForUserFaceInfoUpdate(info, "collect_face_type")
		if err != nil {
			e.OutErr(c, e.ERR_DB_ORM, err.Error())
			return
		}
	}

	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolStudentUpdate(c *gin.Context) {
	var req md.SelfSupportForSchoolStudentUpdateReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	err = svc2.SelfSupportForSchoolStudentUpdate(req)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolStudentAdmission(c *gin.Context) {
	var req md.SelfSupportForSchoolStudentAdmissionReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	err = svc2.SelfSupportForSchoolStudentAdmission(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolStudentDelete(c *gin.Context) {
	var req md.SelfSupportForSchoolStudentDeleteReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	err = svc2.SelfSupportForSchoolStudentDelete(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolTeacherDelete(c *gin.Context) {
	var req md.SelfSupportForSchoolTeacherDeleteReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	//删除 user_identity
	_, err = db.Db.Where("enterprise_id =?", req.EnterpriseId).In("id", req.UserIdentityIds).Delete(model.UserIdentity{})
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	//删除 self_support_for_user_face_info
	_, err = db.Db.In("user_identity_id =?", req.UserIdentityIds).Delete(model.SelfSupportForUserFaceInfo{})
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolWorkerList(c *gin.Context) {
	var req md.SelfSupportForSchoolWorkerListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	resp, total, err := svc2.SelfSupportForSchoolWorkerList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
		"collect_face_type_list": []map[string]interface{}{
			{
				"name":  "个采",
				"value": 1,
			},
			{
				"name":  "集采",
				"value": 2,
			},
		},
	}, nil)
	return
}

func SelfSupportForSchoolWorkerUpdate(c *gin.Context) {
	var req md.SelfSupportForSchoolWorkerUpdateReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(0)
	userIdentity, err := userIdentityDb.GetUserIdentity(req.UserIdentityId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if userIdentity == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}
	userIdentity.IdNo = req.IdNo
	userIdentity.Name = req.Name
	_, err = userIdentityDb.UserIdentityUpdate(req.UserIdentityId, userIdentity, "id_no", "name")
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolWorkerDelete(c *gin.Context) {
	var req md.SelfSupportForSchoolWorkerDeleteReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	//删除 user_identity
	_, err = db.Db.Where("enterprise_id =?", req.EnterpriseId).In("id", req.UserIdentityIds).Delete(model.UserIdentity{})
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolGradeList(c *gin.Context) {
	var req md.SelfSupportForSchoolGradeListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	resp, total, err := svc2.SelfSupportForSchoolGradeList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
	}, nil)
	return
}

func SelfSupportForSchoolClassList(c *gin.Context) {
	var req md.SelfSupportForSchoolClassListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	resp, total, err := svc2.SelfSupportForSchoolClassList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
	}, nil)
	return
}

func SelfSupportForSchoolGradeDelete(c *gin.Context) {
	gradeId := c.Param("id")
	//1、查找当前年级
	gradeDb := db.GradeDb{}
	gradeDb.Set(0)
	grade, err := gradeDb.GetGrade(utils.StrToInt(gradeId))
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	//2、查找当前年级下是否还包含班级
	classDb := db.ClassDb{}
	classDb.Set(grade.Id)
	class, err := classDb.FindClass()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if len(*class) > 0 {
		e.OutErr(c, e.ERR, "当前年级下存在未删除的班级!")
		return
	}
	_, err = gradeDb.GradeDeleteBySession(grade.Id)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolClassDelete(c *gin.Context) {
	classId := c.Param("id")
	//1、查找当前年级
	classDb := db.ClassDb{}
	classDb.Set(0)
	class, err := classDb.GetClass(utils.StrToInt(classId))
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	_, err = classDb.ClassDeleteBySession(class.Id)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	//2、删除当前班级下的所有关联学生
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	_, err = classWithUserDb.DeleteClassWithUserByClass(classId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolAddWorker(c *gin.Context) {
	var req md.SelfSupportForSchoolAddWorkerReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	//1、查找当前身份是否已存在
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(0)
	isHasUserIdentity, err := userIdentityDb.UserIdentityExist(req.EnterpriseId, req.IdNo)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if isHasUserIdentity != nil {
		e.OutErr(c, e.ERR, "当前身份已存在,直接修改身份即可!")
		return
	}

	now := time.Now()
	//2、新增身份信息
	userIdentity := &model.UserIdentity{
		Uid:          0,
		Name:         req.Name,
		IdNo:         req.IdNo,
		Kind:         enum.UserIdentityKindForWorker,
		Identity:     enum.UserIdentityForSelfSupportForWorker,
		EnterpriseId: req.EnterpriseId,
		State:        enum.UserIdentityStateForNormal,
		Memo:         "",
		CreateAt:     now.Format("2006-01-02 15:04:05"),
		UpdateAt:     now.Format("2006-01-02 15:04:05"),
	}
	insertAffected, err := userIdentityDb.UserIdentityInsert(userIdentity)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if insertAffected <= 0 {
		e.OutErr(c, e.ERR_DB_ORM, "新增身份数据失败")
		return
	}

	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolAddTeacher(c *gin.Context) {
	var req md.SelfSupportForSchoolAddTeacherReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	//1、查找当前身份是否已存在
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(0)
	isHasUserIdentity, err := userIdentityDb.UserIdentityExist(req.EnterpriseId, req.IdNo)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if isHasUserIdentity != nil {
		e.OutErr(c, e.ERR, "当前身份已存在,直接修改身份即可!")
		return
	}

	now := time.Now()
	//2、新增身份信息
	userIdentity := &model.UserIdentity{
		Uid:          0,
		Name:         req.Name,
		IdNo:         req.IdNo,
		Kind:         enum.UserIdentityKindForCommon,
		Identity:     enum.UserIdentityForSelfSupportForTeacher,
		EnterpriseId: req.EnterpriseId,
		State:        enum.UserIdentityStateForNormal,
		Memo:         "",
		CreateAt:     now.Format("2006-01-02 15:04:05"),
		UpdateAt:     now.Format("2006-01-02 15:04:05"),
	}
	insertAffected, err := userIdentityDb.UserIdentityInsert(userIdentity)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if insertAffected <= 0 {
		e.OutErr(c, e.ERR_DB_ORM, "新增身份数据失败")
		return
	}

	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolOrdList(c *gin.Context) {
	var req md.SelfSupportForSchoolOrdListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	resp, total, err := svc2.SelfSupportForSchoolOrdList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
		"order_status_list": []map[string]interface{}{
			{
				"name":  enum.SelfSupportForSchoolOrdOrderStatus.String(enum.SelfSupportForSchoolOrdOrderStatusForWait),
				"value": enum.SelfSupportForSchoolOrdOrderStatusForWait,
			},
			{
				"name":  enum.SelfSupportForSchoolOrdOrderStatus.String(enum.SelfSupportForSchoolOrdOrderStatusForSuccess),
				"value": enum.SelfSupportForSchoolOrdOrderStatusForSuccess,
			},
		},
	}, nil)
	return
}

func SelfSupportForSchoolArrearsOrdList(c *gin.Context) {
	var req md.SelfSupportForSchoolArrearsOrdListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	resp, total, err := svc2.SelfSupportForSchoolArrearsOrdList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
	}, nil)
	return
}

func SelfSupportForSchoolArrearsOrdDebtRepay(c *gin.Context) {
	var req md.SelfSupportForSchoolArrearsOrdDebtRepayReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	err, resp := svc.CurlSelfSupportForSchoolOrderDebtRepay(md2.CurlSelfSupportForSchoolOrderDebtRepay{
		OutOrderNo:   req.OutOrderNo,
		MerchantCode: req.MerchantCode,
	})
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, resp, nil)
	return
}

func SelfSupportForSchoolArrearsOrdDebtCancel(c *gin.Context) {
	var req md.SelfSupportForSchoolArrearsOrdDebtCancelReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	err, resp := svc.CurlAlipayPlanetEcocampusApiDebtCancel(md2.CurlAlipayPlanetEcocampusApiDebtCancel{
		OutOrderNo:   req.OutOrderNo,
		MerchantCode: req.MerchantCode,
	})
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, resp, nil)
	return
}

func SelfSupportForSchoolEducateSceneKidsClose(c *gin.Context) {
	userIdentityId := c.DefaultQuery("user_identity_id", "")
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(0)
	identity, err := userIdentityDb.GetUserIdentity(utils.StrToInt(userIdentityId))
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	selfSupportForSchoolInfoDb := db.SelfSupportForSchoolInfoDb{}
	selfSupportForSchoolInfoDb.Set(identity.EnterpriseId)
	selfSupportForSchoolInfo, err := selfSupportForSchoolInfoDb.GetSelfSupportForSchoolInfo()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if selfSupportForSchoolInfo == nil {
		e.OutErr(c, e.ERR_NO_DATA, "当前学校暂未完成《一脸通行入驻》")
		return
	}

	selfSupportForUserFaceInfoDb := db.SelfSupportForUserFaceInfoDb{}
	selfSupportForUserFaceInfoDb.Set(identity.Id)
	selfSupportForUserFaceInfo, err := selfSupportForUserFaceInfoDb.GetSelfSupportForUserFaceInfo()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	sysCfgDb := db.SysCfgDb{}
	sysCfgDb.Set()
	sysCfg := sysCfgDb.SysCfgFindWithDb(enum.OpenAppletAppid, enum.OpenAppletAppPrivateKey, enum.OpenAppletPublicKey)
	err, info := svc.CurlEducateSceneKidsClose(md2.CurlEducateSceneKidsCloseReq{
		Config: struct {
			AliAppId      string `json:"ali_app_id" label:"支付宝开放平台-小程序-appid"`
			AliPrivateKey string `json:"ali_private_key" label:"支付宝开放平台-小程序-应用私钥"`
			AliPublicKey  string `json:"ali_public_key" label:"支付宝开放平台-小程序-支付宝公钥"`
		}{
			AliAppId:      sysCfg[enum.OpenAppletAppid],
			AliPrivateKey: sysCfg[enum.OpenAppletAppPrivateKey],
			AliPublicKey:  sysCfg[enum.OpenAppletPublicKey],
		},
		CertNo:        identity.IdNo,
		SchoolStdCode: selfSupportForSchoolInfo.SchoolStdCode,
		ParentUid:     selfSupportForUserFaceInfo.ParentUserId,
		UserId:        selfSupportForUserFaceInfo.UserId,
	})
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, info, nil)
	return
}

func SelfSupportForSchoolEducateFacepayClose(c *gin.Context) {
	userIdentityId := c.DefaultQuery("user_identity_id", "")
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(0)
	identity, err := userIdentityDb.GetUserIdentity(utils.StrToInt(userIdentityId))
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	selfSupportForSchoolInfoDb := db.SelfSupportForSchoolInfoDb{}
	selfSupportForSchoolInfoDb.Set(identity.EnterpriseId)
	selfSupportForSchoolInfo, err := selfSupportForSchoolInfoDb.GetSelfSupportForSchoolInfo()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if selfSupportForSchoolInfo == nil {
		e.OutErr(c, e.ERR_NO_DATA, "当前学校暂未完成《一脸通行入驻》")
		return
	}

	selfSupportForUserFaceInfoDb := db.SelfSupportForUserFaceInfoDb{}
	selfSupportForUserFaceInfoDb.Set(identity.Id)
	selfSupportForUserFaceInfo, err := selfSupportForUserFaceInfoDb.GetSelfSupportForUserFaceInfo()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	sysCfgDb := db.SysCfgDb{}
	sysCfgDb.Set()
	sysCfg := sysCfgDb.SysCfgFindWithDb(enum.OpenAppletAppid, enum.OpenAppletAppPrivateKey, enum.OpenAppletPublicKey)
	err, info := svc.CurlEducateFacepayClose(md2.CurlEducateFacepayCloseReq{
		Config: struct {
			AliAppId      string `json:"ali_app_id" label:"支付宝开放平台-小程序-appid"`
			AliPrivateKey string `json:"ali_private_key" label:"支付宝开放平台-小程序-应用私钥"`
			AliPublicKey  string `json:"ali_public_key" label:"支付宝开放平台-小程序-支付宝公钥"`
		}{
			AliAppId:      sysCfg[enum.OpenAppletAppid],
			AliPrivateKey: sysCfg[enum.OpenAppletAppPrivateKey],
			AliPublicKey:  sysCfg[enum.OpenAppletPublicKey],
		},
		SchoolStdCode: selfSupportForSchoolInfo.SchoolStdCode,
		FaceUid:       selfSupportForUserFaceInfo.UserId,
	})
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, info, nil)
	return
}
