package hdl

import (
	"applet/app/admin/lib/validate"
	"applet/app/admin/md"
	"applet/app/admin/svc"
	"applet/app/db"
	"applet/app/e"
	"applet/app/utils"
	"github.com/gin-gonic/gin"
	"os"
)

func CentralKitchenForSchoolDataStatisticsList(c *gin.Context) {
	var req md.CentralKitchenForSchoolExportRecordsListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	if req.Limit == 0 {
		req.Limit = 10
	}
	if req.Page == 0 {
		req.Page = 10
	}
	centralKitchenForSchoolExportRecordsDb := db.CentralKitchenForSchoolExportRecordsDb{}
	centralKitchenForSchoolExportRecordsDb.Set()
	list, total, err := centralKitchenForSchoolExportRecordsDb.CentralKitchenForSchoolExportRecordsList(req)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, map[string]interface{}{
		"list":  list,
		"total": total,
		"kind": []map[string]interface{}{
			{
				"name":  "订单列表",
				"value": 1,
			},
			{
				"name":  "退款申请表",
				"value": 2,
			},
			{
				"name":  "学校预定统计表",
				"value": 3,
			},
			{
				"name":  "班级明细表",
				"value": 4,
			},
			{
				"name":  "退款明细表",
				"value": 5,
			},
			{
				"name":  "收款统计表",
				"value": 6,
			},
			{
				"name":  "班级收款明细表",
				"value": 7,
			},
			{
				"name":  "学校预定数量统计表",
				"value": 8,
			},
		},
	}, nil)
	return
}

func CentralKitchenForSchoolDataStatisticsDelete(c *gin.Context) {
	id := c.Param("id")
	centralKitchenForSchoolExportRecordsDb := db.CentralKitchenForSchoolExportRecordsDb{}
	centralKitchenForSchoolExportRecordsDb.Set()
	centralKitchenForSchoolExportRecords, err := centralKitchenForSchoolExportRecordsDb.GetCentralKitchenForSchoolExportRecords(utils.StrToInt(id))
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if centralKitchenForSchoolExportRecords == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到相关记录")
		return
	}
	_, err = centralKitchenForSchoolExportRecordsDb.CentralKitchenForSchoolExportRecordsDelete(id)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolDataStatisticsExport(c *gin.Context) {
	var req md.CentralKitchenForSchoolDataStatisticsExportReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	if req.EnterpriseId != 0 {
		enterpriseDb := db.EnterpriseDb{}
		enterpriseDb.Set()
		enterprise, err1 := enterpriseDb.GetEnterprise(req.EnterpriseId)
		if err1 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err1.Error())
			return
		}
		req.EnterpriseName = enterprise.Name
	}

	go svc.CentralKitchenForSchoolDataStatisticsExport(req)

	e.OutSuc(c, map[string]interface{}{
		"msg": "导出成功，请稍后刷新数据列表",
	}, nil)
	return
}

func NursingHomeDataStatisticsList(c *gin.Context) {
	var req md.NursingHomeExportRecordsListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	if req.Limit == 0 {
		req.Limit = 10
	}
	if req.Page == 0 {
		req.Page = 10
	}

	nursingHomeExportRecordsDb := db.NursingHomeExportRecordsDb{}
	nursingHomeExportRecordsDb.Set()
	list, total, err := nursingHomeExportRecordsDb.NursingHomeExportRecordsList(req)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, map[string]interface{}{
		"list":  list,
		"total": total,
		"kind": []map[string]interface{}{
			{
				"name":  "订单列表",
				"value": 1,
			},
			{
				"name":  "退款申请表",
				"value": 2,
			},
			{
				"name":  "预定统计表",
				"value": 3,
			},
		},
	}, nil)
	return
}

func NursingHomeDataStatisticsDelete(c *gin.Context) {
	id := c.Param("id")
	nursingHomeExportRecordsDb := db.NursingHomeExportRecordsDb{}
	nursingHomeExportRecordsDb.Set()
	centralKitchenForSchoolExportRecords, err := nursingHomeExportRecordsDb.GetNursingHomeExportRecords(utils.StrToInt(id))
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if centralKitchenForSchoolExportRecords == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到相关记录")
		return
	}
	os.RemoveAll("./static" + centralKitchenForSchoolExportRecords.DownloadPath) //移除文件
	_, err = nursingHomeExportRecordsDb.NursingHomeExportRecordsDelete(id)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func NursingHomeDataStatisticsExport(c *gin.Context) {
	var req md.NursingHomeDataStatisticsExportReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	if req.EnterpriseId != 0 {
		enterpriseDb := db.EnterpriseDb{}
		enterpriseDb.Set()
		enterprise, err1 := enterpriseDb.GetEnterprise(req.EnterpriseId)
		if err1 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err1.Error())
			return
		}
		req.EnterpriseName = enterprise.Name
	}

	go svc.NursingHomeDataStatisticsExport(req)

	e.OutSuc(c, map[string]interface{}{
		"msg": "导出成功，请稍后刷新数据列表",
	}, nil)
	return
}

func SelfSupportForSchoolDataStatisticsList(c *gin.Context) {
	var req md.SelfSupportForSchoolExportRecordsListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	if req.Limit == 0 {
		req.Limit = 10
	}
	if req.Page == 0 {
		req.Page = 10
	}

	selfSupportForSchoolExportRecordsDb := db.SelfSupportForSchoolExportRecordsDb{}
	selfSupportForSchoolExportRecordsDb.Set()
	list, total, err := selfSupportForSchoolExportRecordsDb.SelfSupportForSchoolExportRecordsList(req)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, map[string]interface{}{
		"list":  list,
		"total": total,
		"kind": []map[string]interface{}{
			{
				"name":  "学生列表",
				"value": 1,
			},
			{
				"name":  "老师列表",
				"value": 2,
			},
			{
				"name":  "消费明细表",
				"value": 3,
			},
		},
	}, nil)
	return
}

func SelfSupportForSchoolDataStatisticsDelete(c *gin.Context) {
	id := c.Param("id")
	selfSupportForSchoolExportRecordsDb := db.SelfSupportForSchoolExportRecordsDb{}
	selfSupportForSchoolExportRecordsDb.Set()
	selfSupportForSchoolExportRecords, err := selfSupportForSchoolExportRecordsDb.GetSelfSupportForSchoolExportRecords(utils.StrToInt(id))
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if selfSupportForSchoolExportRecords == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到相关记录")
		return
	}
	os.RemoveAll("./static" + selfSupportForSchoolExportRecords.DownloadPath) //移除文件
	_, err = selfSupportForSchoolExportRecordsDb.SelfSupportForSchoolExportRecordsDelete(id)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolDataStatisticsExport(c *gin.Context) {
	var req md.SelfSupportForSchoolDataStatisticsExportReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	if req.EnterpriseId != 0 {
		enterpriseDb := db.EnterpriseDb{}
		enterpriseDb.Set()
		enterprise, err1 := enterpriseDb.GetEnterprise(req.EnterpriseId)
		if err1 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err1.Error())
			return
		}
		req.EnterpriseName = enterprise.Name
	}

	go svc.SelfSupportForSchoolDataStatisticsExport(req)

	e.OutSuc(c, map[string]interface{}{
		"msg": "导出成功，请稍后刷新数据列表",
	}, nil)
	return
}
